@@ -131,14 +131,17 @@ sub saveHtmlFile {
 ##  @ppairs = $CLASS_OR_OBJECT->align($mp1,$mp2)
 ## \@ppairs = $CLASS_OR_OBJECT->align($mp1,$mp2)
 ##  + aligns subprofile-pairs from $mp1 and $mp2
+##  + $mp1, $mp2 are either:
+##    - HASH-refs with a 'profiles' key (e.g. DiaColloDB::Profile::Multi objects)
+##    - ARRAY-refs of DiaColloDB::Profile-like objects to align
 ##  + subprofiles are aligned in stored order
 ##  + arguments must be EITHER singletons (1 subprofile) OR of same size
 ##    - this lets you compare e.g. a global profile with a sliced one by
 ##      something like PDL's "implicit threading"
 sub align {
   my ($that,$mpa,$mpb) = @_;
-  my $psa = $mpa->{profiles};
-  my $psb = $mpb->{profiles};
+  my $psa = UNIVERSAL::isa($mpa,'HASH') ? $mpa->{profiles} : $mpa;
+  my $psb = UNIVERSAL::isa($mpb,'HASH') ? $mpb->{profiles} : $mpb;
   if (@$psa==1 || @$psb==1 || @$psa==@$psb) {
     ##-- align cyclically (allow slices)
     my @pairs = map {
@@ -206,31 +209,21 @@ sub trimPairs {
   $opts{diff}   //= 'adiff';
 
   if ($opts{global}) {
-    ##-- trim globally
+    ##-- (pre-)trim globally
     my $gpa = DiaColloDB::Profile::Multi->sumover(luniq([map {$_->[0]} @$ppairs]), eps=>$opts{eps});
     my $gpb = DiaColloDB::Profile::Multi->sumover(luniq([map {$_->[1]} @$ppairs]), eps=>$opts{eps});
-    my (%keep);
-    if (DiaColloDB::Profile::Diff->diffpretrim($opts{diff})) {
-      ##-- pre-trim
-      %keep = map {($_=>undef)} (@{$gpa->which(%opts)}, @{$gpb->which(%opts)});
-      $gpa->trim(keep=>\%keep);
-      $gpb->trim(keep=>\%keep);
-    }
+    DiaColloDB::Profile::Diff->pretrim($gpa,$gpb,%opts);
 
     my $gdiff = DiaColloDB::Profile::Diff->new($gpa,$gpb, diff=>$opts{diff});
-    %keep     = map {($_=>undef)} @{$gdiff->which( DiaColloDB::Profile::Diff->diffkbest($opts{diff})=>$opts{kbest} )};
+    my %keep  = map {($_=>undef)} @{$gdiff->which( DiaColloDB::Profile::Diff->diffkbest($opts{diff})=>$opts{kbest} )};
     $_->trim(keep=>\%keep) foreach (grep {$_} map {@$_} @$ppairs);
   }
-  elsif (DiaColloDB::Profile::Diff->diffpretrim($opts{diff})) {
+  else {
     ##-- (pre-)trim locally
-    my ($pa,$pb,%keep);
     foreach (@$ppairs) {
-      ($pa,$pb) = @$_;
-      %keep = map {($_=>undef)} (($pa ? @{$pa->which(%opts)} : qw()), ($pb ? @{$pb->which(%opts)} : qw()));
-      $pa->trim(keep=>\%keep) if ($pa);
-      $pb->trim(keep=>\%keep) if ($pb);
+      DiaColloDB::Profile::Diff->pretrim(@$_[0,1],%opts);
     }
- }
+  }
 
   return $ppairs;
 }
